
/*
 Treatment Effects
 
 Goal: Impact of smoking on birth weight
 
	1.  Open database from Stata database
 
	2.  Check Balanced characteristics
	
	3.  Estimate Treatment Effects (Average treatment)

*/


clear all
set more off
set matsize 5000


/*
        1. Open database from Stata database
*/

**From the stata data 
webuse bweightex.dta,clear

describe  mbsmoke bweight prenatal1 mmarried mage fbaby


/*
        1. Open database from Stata database
*/

***************************************************************************************

**Balanced characteristics: Are smoker and non-smoker different ?
table mbsmoke,  c(mean mage  mean prenatal1 mean fbaby)
ttest mage, by(mbsmoke)
graph bar mage, over(mbsmoke)

** Graph birth weight and mother's age by group

twoway (scatter   bweight mage if mbsmoke==1)(scatter  bweight mage if mbsmoke==0), ///
legend(order(1 "Smoker" 2 "Non-smoker" )) graphregion(color(white)) 

/*
        2. Estimate Treatment Effects (Average treatment)
*/

** Linear regressin
reg bweight mbsmoke 

** Linear regression with control
reg bweight mbsmoke prenatal1 mmarried mage fbaby

** Regression adjustment : Average treatment effects
teffects ra (bweight mmarried mage prenatal1 fbaby) (mbsmoke),ate
est store pop
 
** Regression adjustment : Average treatment effects among treated
teffects ra (bweight prenatal1 mmarried mage fbaby)(mbsmoke),atet
est store ate


*outreg2 [pop ate] using  "C:\Users\yaya1\Dropbox\Fall2020\ECON338\Stata Conference\Conference2\Results\ATE_results.xls", excel word replace 

**inverse-probability weights (IPW)

logistic mbsmoke mage
predict ps

twoway (scatter  ps mage ), ///
legend(order(1 "Prob"  )) graphregion(color(white)) 

**IPW
gen ips=.
replace ips = 1/ps if mbsmoke==1
replace ips = 1/(1-ps) if mbsmoke==0

**Using reg command
reg bweight mbsmoke prenatal1 mmarried mage fbaby [pweight=ips]

**command
teffects ipw (bweight) (mbsmoke mmarried mage prenatal1 fbaby, probit)
 
 
twoway (scatter  bweight mage if mbsmoke==1,yaxis(1))(scatter  bweight mage if mbsmoke==0,yaxis(1))(scatter  ps mage,yaxis(2)), ///
legend(order(1 "Smoker" 2 "Non-smoker" 3 "Pr" )) graphregion(color(white)) 

